/**
 * Copyright 2007 - 2008 Skyway Software, Inc.
 * 
 * Skyway Software, Inc. licenses this file to You under the Apache License, 
 * Version 2.0(the "License"); you may not use this file except in compliance 
 * with the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.skyway.spring.util.dao.call;

import org.springframework.jdbc.core.SqlParameter;

/**
 * Represents an input parameter with a logical name
 * and a value.
 * 
 * NOTE: The SqlParameterValue class provided by Spring 
 * provides a means of setting a value but it does not
 * provide a means of setting the name. 
 * 
 */
public class NamedSqlParameterValue extends SqlParameter {
	private Object value;
	
	public NamedSqlParameterValue(String name) {
		this(name, null);
	}
	
	/**
	 * We pass the superclass 0 for the SQL type.  We don't really
	 * use it.  Any calls use the SqlParameter's that are constructed
	 * from the database meta data.
	 */
	public NamedSqlParameterValue(String name, Object value) {
		super(name, 0);
		this.value = value;
	}

	public NamedSqlParameterValue(String name, int sqlType, String typeName, Object value) {
		super(name, sqlType, typeName);
		this.value = value;
	}
	
	public Object getValue() {
		return value;
	}

	public void setValue(Object value) {
		this.value = value;
	}
}
