/**
 * Copyright 2007 - 2008 Skyway Software, Inc.
 * 
 * Skyway Software, Inc. licenses this file to You under the Apache License, 
 * Version 2.0(the "License"); you may not use this file except in compliance 
 * with the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.skyway.spring.util.dao.call.oracle;

import java.lang.reflect.Constructor;
import java.lang.reflect.Method;

@SuppressWarnings("nls")
public abstract class OracleIntrospector {
	public abstract String getClassName();
	public abstract Object getInstance();
	
	protected Object findAndExecuteMethod(String methodName, Object... args){
		Class<?> classToExecute;
		Method method;
		
		try {
			classToExecute = findClassForName(getClassName());
		
			method = findMethod(classToExecute, methodName, args);

			return method.invoke(getInstance(), args);
		} catch (Exception e) {
			throw new RuntimeException("Unable to execute method [" + methodName + "] on class [" + getClassName() + "].  Make sure the oracle jar is on your classpath.", e);
		}
	}

	protected Object findAndExecuteConstructor(Object... args){
		Constructor<?> constructor;
		Class<?> classToExecute;
		
		try {
			classToExecute = findClassForName(getClassName());
		
			constructor = findConstructor(classToExecute, args);

			return constructor.newInstance(args);
		} catch (Exception e) {
			throw new RuntimeException("Unable to instantiate instance of class [" + getClassName() + "].  Make sure the oracle jar is on your classpath.", e);
		}
	}
	
	public static Class<?> findClassForName(String className){
		try {
			return Class.forName(className);
		} catch (ClassNotFoundException e) {
			throw new RuntimeException("Unable to find class [" + className + "].  Make sure the oracle jar is on your classpath.", e);
		}
	}

	public static Method findMethod(Class<?> classDefinition, String methodName, Object... args){
		Class<?>[] argumentTypes = new Class<?>[args.length];
		int index = 0;
		
		try {
			for (Object argument : args){
				argumentTypes[index++] = argument.getClass();
			}
			
			return classDefinition.getMethod(methodName, argumentTypes);
		} catch (NoSuchMethodException e) {
			throw new RuntimeException("Unable to find method [" + methodName + "] on class [" + classDefinition.getName() + "].  Make sure the oracle jar is on your classpath.", e);
		}
	}

	public static Constructor<?> findConstructor(Class<?> classDefinition, Object... args){
		Class<?>[] argumentTypes = new Class<?>[args.length];
		int index = 0;
		
		try {
			for (Object argument : args){
				argumentTypes[index++] = argument.getClass();
			}
			
			return classDefinition.getConstructor(argumentTypes);
		} catch (NoSuchMethodException e) {
			throw new RuntimeException("Unable to find constructor on class [" + classDefinition.getName() + "].  Make sure the oracle jar is on your classpath.", e);
		}
	}
}
