/**
 * Copyright 2007 - 2008 Skyway Software, Inc.
 * 
 * Skyway Software, Inc. licenses this file to You under the Apache License, 
 * Version 2.0(the "License"); you may not use this file except in compliance 
 * with the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.skyway.spring.util.dao.call.oracle;

import org.skyway.common.util.ConversionUtils;
import org.skyway.spring.util.dao.query.SQLResultsProvider;

public class OracleSQLResultsProvider extends SQLResultsProvider {
	private static final long serialVersionUID = 1L;

	/**
	 * When we get a result set back from an oracle stored procedure call
	 * we get a oracle.sql.TIMESTAMP result instead of a java.sql.Timestamp.
	 * We just ask the oracle instance for an instance of the jdbc type.
	 */
	@Override
	protected <T> T convertValue(Object sourceValue, Class<T> targetType){
		if (getTIMESTAMPClass().isInstance(sourceValue)){
			sourceValue = new OracleTIMESTAMP(sourceValue).timestampValue();
		}
		
		T convertedValue = (T) ConversionUtils.convert(sourceValue, targetType);
		
		return convertedValue;
	}
	
	protected Class<?> getTIMESTAMPClass(){
		return OracleIntrospector.findClassForName(OracleTIMESTAMP.getTIMESTAMPClassName());
	}
}
