/**
 * Copyright 2007 - 2008 Skyway Software, Inc.
 * 
 * Skyway Software, Inc. licenses this file to You under the Apache License, 
 * Version 2.0(the "License"); you may not use this file except in compliance 
 * with the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.skyway.spring.util.dao.query;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.PreparedStatementCreator;
import org.springframework.jdbc.core.SqlProvider;

public class FixedPreparedStatementCreator implements PreparedStatementCreator, SqlProvider {

	private Object[] parameters;
	private int startResult;
	private int maxResults;
	private String sql;
	
	public FixedPreparedStatementCreator(String sql, int startResult, int maxResults){
		this.sql = sql;
		this.startResult = startResult;
		this.maxResults = maxResults;
	}
	
	public String getSql(){
		return sql;
	}

	public void prepare(Object... parameters){
		this.parameters = parameters;
	}
	
	public PreparedStatement createPreparedStatement(Connection connection) throws SQLException{
		int resultSetConcurrency = ResultSet.CONCUR_READ_ONLY;
		int resultSetType = ResultSet.TYPE_FORWARD_ONLY;
		PreparedStatement statement;
		
		if (sql == null || sql.length() == 0){
			throw new RuntimeException("Query is empty.");
		}
		
		if (startResult > 0){
			resultSetType = ResultSet.TYPE_SCROLL_INSENSITIVE;
		}
		
		statement = connection.prepareStatement(sql, resultSetType, resultSetConcurrency);
		
		if (maxResults >= 0){
			if (startResult > 0){
				maxResults += startResult;
			}
			
			statement.setMaxRows(maxResults);
		}
		
		if (parameters != null){
			for (int index = 0; index < parameters.length; index++){
				statement.setObject(index + 1, parameters[index]);
			}
		}
		
		return statement;
	}
}
