/**
 * Copyright 2007 - 2008 Skyway Software, Inc.
 * 
 * Skyway Software, Inc. licenses this file to You under the Apache License, 
 * Version 2.0(the "License"); you may not use this file except in compliance 
 * with the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.skyway.spring.util.dao.query;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;

import org.skyway.common.util.ConversionUtils;

public class JPQLResultsProvider implements Serializable {
	private static final long serialVersionUID = 1L;

	private Object jpqlResults;
	
	public JPQLResultsProvider(Object jpqlResults){
		this.jpqlResults = jpqlResults;
	}
	
	@SuppressWarnings("unchecked")
	public <T> T getSingleResult(int position, Class<T> targetClass) {
		Object dbResult = null;
		T result = null;
		
		if (jpqlResults instanceof Collection) {
			if (((Collection<?>) jpqlResults).size() > 0){
				dbResult = ((Collection<?>) jpqlResults).iterator().next();
			}
		} else {
			dbResult = jpqlResults;
		}

		if (dbResult != null){
			if (dbResult.getClass().isArray()) {
				dbResult = ((Object[]) dbResult)[position];
			}
			
			result = ConversionUtils.convert(dbResult, targetClass);
		}

		return result;
	}
	
	public <T> Set<T> getResultsAsSet(int position, Class<T> targetClass) {
		Set<T> results = new LinkedHashSet<T>();
		
		getResults(position, targetClass, results);
		
		return results;
	}
	
	public <T> List<T> getResultsAsList(int position, Class<T> targetClass) {
		List<T> results = new ArrayList<T>();
		
		getResults(position, targetClass, results);
		
		return results;
	}
	
	@SuppressWarnings("unchecked")
	public <T> void getResults(int position, Class<T> targetClass, Collection<T> results) {
		Object dbResult = null;
		T positionedResult;

		if (jpqlResults instanceof Collection) {
			results.addAll((Collection<T>)jpqlResults);
			if (results.size() > 0){
				dbResult = ((Collection<T>) jpqlResults).iterator().next();
			}
		} else {
			results.add((T)jpqlResults);
			dbResult = jpqlResults;
		}

		if (dbResult != null && dbResult.getClass().isArray()) {
			for (Iterator i = results.iterator(); i.hasNext();) {
				positionedResult = ConversionUtils.convert(((Object[]) i.next())[position], targetClass);
				results.add(positionedResult);
			}
		}
	}
}
