/**
 * Copyright 2007 - 2008 Skyway Software, Inc.
 * 
 * Skyway Software, Inc. licenses this file to You under the Apache License, 
 * Version 2.0(the "License"); you may not use this file except in compliance 
 * with the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.skyway.spring.util.databinding;

import java.text.NumberFormat;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.propertyeditors.CustomNumberEditor;

/**
 * Number editor that sets the value to null when the value received
 * is NaN.  DOJO likes to pass up NaN for numbers even if you just tab
 * through a field without making any changes.
 * 
 * @author jperkins
 *
 */
@SuppressWarnings("unchecked")
public class NaNHandlingNumberEditor extends CustomNumberEditor {
	private static final String NaN = "NaN"; //$NON-NLS-1$
	
	public NaNHandlingNumberEditor(Class numberClass, boolean allowEmpty) throws IllegalArgumentException {
		super(numberClass, allowEmpty);
	}

	public NaNHandlingNumberEditor(Class numberClass, NumberFormat numberFormat, boolean allowEmpty) throws IllegalArgumentException {
		super(numberClass, numberFormat, allowEmpty);
	}
	
	@Override
	public void setAsText(String text) throws IllegalArgumentException {
		if (StringUtils.equals(text, NaN)){ 
			setValue(null);
			return;
		}else{
			super.setAsText(text);
		}
	}
}
