/**
 * Copyright 2007 - 2008 Skyway Software, Inc.
 * 
 * Skyway Software, Inc. licenses this file to You under the Apache License, 
 * Version 2.0(the "License"); you may not use this file except in compliance 
 * with the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.skyway.spring.util.webservice;

import org.apache.commons.lang.StringUtils;

/**
 * Represents credential information that will be applied to outgoing web service calls.
 * 
 * @author jperkins
 *
 */
public class WebServiceInvocationCredentials {
	public static final String AUTHENTICATION_TYPE_WS_SECURITY = "ws-security";
	public static final String AUTHENTICATION_TYPE_BASIC = "basic";
	
	private String authenticationType;
	private String userId;
	private String password;
	private boolean hashPassword;
	
	public WebServiceInvocationCredentials(String authenticationType, String userId, String password, boolean hashPassword){
		this.authenticationType = authenticationType;
		this.userId = userId;
		this.password = password;
		this.hashPassword = hashPassword;
	}

	public String getAuthenticationType() {
		return authenticationType;
	}

	public String getUserId() {
		return userId;
	}

	public String getPassword() {
		return password;
	}

	public boolean isHashPassword() {
		return hashPassword;
	}
	
	public boolean isAuthenticationBasic(){
		return StringUtils.equalsIgnoreCase(getAuthenticationType(), AUTHENTICATION_TYPE_BASIC);
	}
	
	public boolean isAuthenticationWsSecurity(){
		return StringUtils.equalsIgnoreCase(getAuthenticationType(), AUTHENTICATION_TYPE_WS_SECURITY);
	}
}
