/**
 * Copyright 2007 - 2008 Skyway Software, Inc.
 * 
 * Skyway Software, Inc. licenses this file to You under the Apache License, 
 * Version 2.0(the "License"); you may not use this file except in compliance 
 * with the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */package org.skyway.spring.util.webservice.cxf;

import java.io.IOException;

import javax.security.auth.callback.Callback;
import javax.security.auth.callback.CallbackHandler;
import javax.security.auth.callback.UnsupportedCallbackException;

import org.apache.ws.security.WSPasswordCallback;
import org.springframework.security.Authentication;
import org.springframework.security.AuthenticationException;
import org.springframework.security.AuthenticationManager;
import org.springframework.security.context.SecurityContext;
import org.springframework.security.context.SecurityContextHolder;
import org.springframework.security.context.SecurityContextImpl;
import org.springframework.security.providers.UsernamePasswordAuthenticationToken;

/**
 * Handles authentication of incoming web service calls by asking the spring
 * authentication manager to authenticate the credentials.  If the credentials
 * are valid, the SecurityContext is initialized and set.
 * 
 * @author jperkins
 *
 */
public class AuthenticateCredentialsHandler implements CallbackHandler {
	
	private AuthenticationManager authenticationManager;
	
	AuthenticateCredentialsHandler(AuthenticationManager authenticationManager) {
		super();
		this.authenticationManager = authenticationManager;
	}

	public void handle(Callback[] callbacks) throws IOException, UnsupportedCallbackException {
		WSPasswordCallback passwordCallback = (WSPasswordCallback) callbacks[0];

		authenticate(passwordCallback);
	}

	@SuppressWarnings("deprecation")
	private void authenticate(WSPasswordCallback passwordCallback){
		String userName = passwordCallback.getIdentifer();
		String password = passwordCallback.getPassword();
		
		Authentication authentication = new UsernamePasswordAuthenticationToken(userName, password);
		try {
			authentication = authenticationManager.authenticate(authentication);
			if (authentication.isAuthenticated()) {
				// Set the security context
				SecurityContext securityContext = new SecurityContextImpl();
				securityContext.setAuthentication(authentication);
				SecurityContextHolder.setContext(securityContext);
			} else {
				throw new RuntimeException("Invalid credentials."); //$NON-NLS-1$
			}
		} catch (AuthenticationException e) {
			throw new RuntimeException("Invalid credentials."); //$NON-NLS-1$
		}
		
	}
}
