/**
 * Copyright 2007 - 2008 Skyway Software, Inc.
 * 
 * Skyway Software, Inc. licenses this file to You under the Apache License, 
 * Version 2.0(the "License"); you may not use this file except in compliance 
 * with the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.skyway.spring.util.webservice.cxf;

import java.net.URL;

import org.apache.cxf.message.Message;
import org.apache.cxf.transport.http.HttpBasicAuthSupplier;
import org.skyway.spring.util.webservice.WebServiceInvocationCredentials;
import org.skyway.spring.util.webservice.WebServiceInvocationCredentialsHolder;

/**
 * Supplies credentials to outgoing web service calls that require basic http authentication.
 * 
 * @author jperkins
 *
 */
public class HttpBasicAuthenticationSupplier extends HttpBasicAuthSupplier {
	public HttpBasicAuthenticationSupplier() {
	}

	@Override
	public UserPass getPreemptiveUserPass(String conduitName, URL currentURL, Message message) {
		return getUserPass(message);
	}

	@Override
	public UserPass getUserPassForRealm(String arg0, URL arg1, Message arg2, String arg3) {
		return getUserPass(arg2);
	}

	private UserPass getUserPass(Message message) {
		if (Boolean.TRUE.equals(message.get(Message.REQUESTOR_ROLE))) {
			WebServiceInvocationCredentials parameters = WebServiceInvocationCredentialsHolder.get();

			if (parameters != null && parameters.isAuthenticationBasic()) {
				return createUserPass(parameters.getUserId(), parameters.getPassword());
			}
		}

		return null;
	}
}
